pub enum ClientError {
Show 22 variants
Jsonrpsee(ClientError),
SubxtError(Error),
RpcError(Error),
SqlxError(Error),
CodecError(Error),
SubmitError(SubmitError),
TransactError(EthTransactError),
ConversionFailed,
BlockNotFound,
ContractNotFound,
EthExtrinsicNotFound,
TxFeeNotFound,
TxDecodingFailed,
RecoverEthAddressFailed,
LogFilterFailed(Error),
ReceiptDataNotFound,
EthereumBlockNotFound,
ReceiptDataLengthMismatch,
Timeout,
NoEstimationMethodSucceeded,
ChainMismatch,
SyncBoundaryMismatch,
}Expand description
The error type for the client.
Variants
Jsonrpsee(ClientError)
A [jsonrpsee::core::ClientError] wrapper error.
SubxtError(Error)
A [subxt::Error] wrapper error.
RpcError(Error)
SqlxError(Error)
A [sqlx::Error] wrapper error.
CodecError(Error)
A [codec::Error] wrapper error.
SubmitError(SubmitError)
author_submitExtrinsic failed.
TransactError(EthTransactError)
Transact call failed.
ConversionFailed
A decimal conversion failed.
BlockNotFound
The block hash was not found.
ContractNotFound
The contract was not found.
EthExtrinsicNotFound
TxFeeNotFound
The transaction fee could not be found
TxDecodingFailed
Failed to decode a raw payload into a signed transaction.
RecoverEthAddressFailed
Failed to recover eth address.
LogFilterFailed(Error)
Failed to filter logs.
ReceiptDataNotFound
Receipt storage was not found.
EthereumBlockNotFound
Ethereum block was not found.
ReceiptDataLengthMismatch
Receipt data length mismatch.
Timeout
Transaction submission timeout.
NoEstimationMethodSucceeded
All of the estimation methods eth_estimate, eth_transact_with_config, and
eth_transact were not found and therefore none of the estimation methods succeeded.
ChainMismatch
Chain identity mismatch between stored genesis and connected node.
SyncBoundaryMismatch
Stored sync boundary does not match the connected node.