pub type SubstrateBlock = OnlineClientAtBlock<SrcChainConfig>;Expand description
A handle to a Substrate block at a specific height.
Aliased Type
pub struct SubstrateBlock { /* private fields */ }pub type SubstrateBlock = OnlineClientAtBlock<SrcChainConfig>;A handle to a Substrate block at a specific height.
pub struct SubstrateBlock { /* private fields */ }